@@ -39,7 +39,7 @@ class DCDF(object):
         return ret_vals
 
 
-class RibCriteria():
+class RibCriteria:
     def __init__(self, dcdf):
         self._dcdf = dcdf
 
@@ -54,6 +54,8 @@ class RibCriteria():
             return 0.0
         sus = 100. * (us / (1.0 - (age - 25.) * 0.0051))
         result = self._dcdf.calculate_dcdf(sus)
+        #from .standard_functions import StandardFunction
+        #xy = StandardFunction.ccdf_sigmoid(param_dict={"x": sus, "x0": 3, "k": 1})
         return result
 
     def calc_num_frac(self, rib_ids, risk):
