@@ -62,7 +62,7 @@ class StandardFunction:
         :param data_vector:
         :return:
         """
-        return data_vector
+        return np.min(data_vector)
 
     @staticmethod
     def mult(data_vector_1: np.ndarray, data_vector_2: np.ndarray, units):
@@ -468,26 +468,23 @@ class StandardFunction:
 
         return np.array([histogram_data]).reshape(-1, 1)
 
-    @staticmethod
-    def surface_strain(object_data: dict, units):
-
-        part_ids = object_data["part_ids"]
-        part_data = object_data["part_data"]
-        part_idx = object_data["part_idx"]
-
-
-        for part_id in part_ids:
-            index = part_idx[part_id]
-            data = part_data[part_id]
-            element_ids = np.unique(index[:, 0])
-
-            for element_id in element_ids:
-                row_ids = np.where(index[:, 0] == element_id)[0]
-
-                reduced_integration_point_data = data[:, row_ids, :]
-
-                a = 0
-
+    # @staticmethod
+    # def surface_strain(object_data: dict, units):
+    #
+    #     part_ids = object_data["part_ids"]
+    #     part_data = object_data["part_data"]
+    #     part_idx = object_data["part_idx"]
+    #
+    #     for part_id in part_ids:
+    #         index = part_idx[part_id]
+    #         data = part_data[part_id]
+    #         element_ids = np.unique(index[:, 0])
+    #         for element_id in element_ids:
+    #             row_ids = np.where(index[:, 0] == element_id)[0]
+    #
+    #             reduced_integration_point_data = data[:, row_ids, :]
+    #
+    #             a = 0
 
     @staticmethod
     def osccar_rib_criteria(object_data: dict, nr_largest_elements: int, age: float, risk_curve, units):
@@ -689,7 +686,6 @@ class StandardFunction:
         obj_calc = ObjectCalcUtil()
         (function_overall_tension_compression, integration_point_function) = \
             obj_calc.retrieve_functions(selection_tension_compression, integration_point)
-
         part_max_elment = {}
 
         for part_id in part_ids:
@@ -721,6 +717,46 @@ class StandardFunction:
 
         return np.array([part_max_elment[i][0] for i in part_max_elment])
 
+    @staticmethod
+    def stress_strain_time_history(object_data: dict, selection_tension_compression: str, integration_point: str,
+                               percentile: float, interpolation:str, units):
+        """
+
+        :param object_data: data container for parts of the defined object
+        :param selection_tension_compression: selection how principle components are treated
+        :param integration_point: selection how integration points are treated
+        :param percentile: percentile caclulation of the resulting data_matrix (time x nr_elements in object), for each
+        timestep the nth percentile value is returned
+        :param interpolation: percentile calculation
+
+        :return: percentile element value over time
+        """
+
+        part_ids = object_data["part_ids"]
+        part_data = object_data["part_data"]
+        part_idx = object_data["part_idx"]
+
+        obj_calc = ObjectCalcUtil()
+        (function_overall_tension_compression, integration_point_function) = \
+            obj_calc.retrieve_functions(selection_tension_compression, integration_point)
+
+        element_data = np.empty((len(object_data["time"]),0))
+        for idx, part_id in enumerate(part_ids):
+            data = part_data[part_id]
+            index = part_idx[part_id]
+            element_ids = np.unique(index[:, 0])
+            part_elem_data = np.empty(shape=(len(element_ids), len(object_data["time"])))
+            for elem_idx, element_id in enumerate(element_ids):
+                row_ids = np.where(index[:, 0] == element_id)[0]
+                reduced_integration_point_data = integration_point_function(data[:, row_ids, :], axis=1)
+                result_data = function_overall_tension_compression(reduced_integration_point_data, axis=1)
+                part_elem_data[elem_idx] = result_data
+            element_data = np.hstack((element_data, part_elem_data.T))
+
+        element_data = element_data.T
+
+        return np.nanpercentile(element_data, percentile, interpolation=interpolation, axis=0) # element_data[np.arange(element_data.shape[0]), column_index_of_n_highest]
+
 
 
     @staticmethod
