@@ -363,10 +363,9 @@ class BinoutData(object):
         # only necessary functions
         negative_intersection = [val for val in self._defined_types if val not in elements]
         if len(negative_intersection) != 0:
-            self._logger.emit(LOGConstants.ERROR[0], "binout keys: " + " ".join(elements))
-            self._logger.emit(LOGConstants.ERROR[0], "missing keys: " + " ".join(negative_intersection))
-            self._logger.emit(LOGConstants.ERROR[0], 'failed to read ' + self._name + ' data!')
-            return False
+            self._logger.emit(LOGConstants.WARNING[0], "binout keys: " + " ".join(elements))
+            self._logger.emit(LOGConstants.WARNING[0],
+                              "Your definition file tries to access the following undefined keys : " + " ".join(negative_intersection))
         return True
 
     def get_data_of_defined_json(self, json_object, data_offsets):
@@ -405,6 +404,8 @@ class BinoutData(object):
         data_array = None
         for tpl in converted_tuples:
             d = copy.copy(self.get_measurement_channel(id_=ids[tpl[0]], channel_name=tpl[1]))
+            if len(d) == 0:
+                return None
             if tpl[1] == "time":
                 d -= d[data_offset, 0]
             data_array = d[data_offset:data_delta_t] if data_array is None else np.append(data_array,
