@@ -86,6 +86,7 @@ class DynasaurDefinitions:
         self._seatbelt = {}
         self._energy_part = {}
         self._energy_global = {}
+        self._abstat = {}
         self._riskfunction = {DefFileConstants.FUNC_CRITERIA: {},
                               DefFileConstants.FUNC_DATA_VISUALIZATION: {}}
 
@@ -175,6 +176,8 @@ class DynasaurDefinitions:
             d = self._disbout
         elif data_container == "disbout_part":
             d = self._part_disbout
+        elif data_container == "abstat":
+            d = self._abstat
 
         if name not in d.keys() or len(d) == 0:
             self._logger.emit(LOGConstants.ERROR[0],
@@ -238,7 +241,7 @@ class DynasaurDefinitions:
         # only store ids not the entire dict would cause side effects
         self._objects[name].set_parts(part_ids)
 
-    def _get_all_data_types_from_json(self, d, ls):
+    def get_all_data_types_from_json(self, d, ls):
         """
         get all data types
 
@@ -251,7 +254,7 @@ class DynasaurDefinitions:
             if key is None:
                 continue
             if isinstance(d[key], dict):
-                data_type = self._get_all_data_types_from_json(d[key], ls)
+                data_type = self.get_all_data_types_from_json(d[key], ls)
                 if data_type is not None and data_type not in ls:
                     if isinstance(data_type, list):
                         for type_ in data_type:
@@ -270,9 +273,9 @@ class DynasaurDefinitions:
         """
         ls = []
         if DefinitionConstants.CRITERIA == plugin_name:
-            self._get_all_data_types_from_json(self._criteria, ls)
+            self.get_all_data_types_from_json(self._criteria, ls)
         elif DefinitionConstants.DATA_VIS == plugin_name:
-            self._get_all_data_types_from_json(self._data_vis, ls)
+            self.get_all_data_types_from_json(self._data_vis, ls)
         else:
             assert False
         return ls
@@ -367,6 +370,8 @@ class DynasaurDefinitions:
                 self.__set_object(json_object)
             elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.NODE:
                 self._set_datacontainer_defintion(json_object, self._node)
+            elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.AIRBAG:
+                self._set_datacontainer_defintion(json_object, self._abstat)
             elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.DISBOUT:
                 self._set_datacontainer_defintion(json_object, self._disbout)
             elif json_object[JsonConstants.TYPE] == ObjectConstantsForData.ELEMENT:
