@@ -1025,7 +1025,10 @@ class Glstat(BinoutData):
         INFO: own implementation in glstat.py due to missing ids for glstat data
         """
         data = {}
-        for key in self.__class__.DATA_CHANNEL_TYPES:
+        available_channels = [value for value in self.__class__.DATA_CHANNEL_TYPES if
+                              value in self._binout.read(self._name)]
+
+        for key in available_channels:
             type_data = self._binout.read(self._name, key)
 
             if type_data.shape[0] != 0:
