@@ -1,19 +1,20 @@
 import h5py
 import numpy as np
 
-from ..utils.constants import LOGConstants, UnitsConstants, MadymoConstants, DataChannelTypesNodout, DataChannelTypesSecforc
+from ..utils.constants import LOGConstants, UnitsConstants, MadymoConstants, DataChannelTypesNodout, \
+    DataChannelTypesSecforc
 from ..utils.logger import ConsoleLogger
 from ..data.dynasaur_definitions import DynasaurDefinitions
 
 
 class MadymoData:
 
-    def _extratct_data(self, node, data_type, idx_mady_mo_data):
+    def _extratct_data(self, node, data_type, idx_madymo_data):
         """
 
         :param node:
         :param data_type:
-        :param idx_mady_mo_data:
+        :param idx_madymo_data:
         :return:
         """
         for idx, id_ in enumerate(self._d['nodout']['ids']):
@@ -21,7 +22,82 @@ class MadymoData:
             for key in keys:
                 id_to_compare = ''.join([chr(i) for i in list(node[key].attrs.items())[0][1] if i != 0]).split(" ")[0]
                 if id_to_compare == id_:
-                    self._d["nodout"][data_type][:, idx] = node[key]["Y_VALUES"][idx_mady_mo_data, :]
+                    self._d["nodout"][data_type][:, idx] = node[key]["Y_VALUES"][idx_madymo_data, :]
+
+    def _extract_data_energy(self, node, data_type, ids,  enegry_type):
+        """
+
+        :param node:
+        :param enegry_type:
+        :param idx_madymo_data:
+        :return:
+        """
+        keys = [i for i in node.keys() if i.startswith("SIGNAL")]
+        for key in keys:
+            id_string = ''.join([chr(i) for i in list(node[key].attrs.items())[0][1] if i != 0]).strip()
+            id_ = [i for i in id_string.split() if i.startswith("/")][0]
+
+            if id_ not in ids:
+                continue
+            insert_idx = ids.index(id_)
+            if id_string.startswith("total energy") and enegry_type == "total_energy":
+                self._d[data_type]["total_energy"][:, insert_idx] = node[key]["Y_VALUES"][0, :]
+
+            elif id_string.startswith("kinetic energy") and enegry_type == "kinetic_energy":
+                self._d[data_type]["kinetic_energy"][:, insert_idx] = node[key]["Y_VALUES"][0, :]
+
+            elif id_string.startswith("total hourglass energy") and enegry_type == "hourglass_energy":
+                self._d[data_type]["hourglass_energy"][:, insert_idx] = node[key]["Y_VALUES"][0, :]
+
+            elif id_string.startswith("work done by external loading") and enegry_type == "external_work":
+                self._d[data_type]["external_work"][:, insert_idx] = node[key]["Y_VALUES"][0, :]
+
+            elif id_string.startswith("work done by contact forces") and enegry_type == "sliding_interface_energy":
+                self._d[data_type]["sliding_interface_energy"][:, insert_idx] = node[key]["Y_VALUES"][0, :]
+
+
+
+            # print(''.join([chr(i) for i in list(node[key].attrs.items())[0][1] if i != 0]).strip().split(" ")[0])
+            # print(''.join([chr(i) for i in list(node[key].attrs.items())[0][1] if i != 0]).strip().split(" "))
+
+    def _add_energy_ids(self, node, data_type):
+        """
+
+        :param node:
+        :param data_type:
+        :return:
+        """
+        signals = [signal for signal in node.keys() if signal.startswith("SIGNAL")]
+        for signal in signals:
+            id_string = ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip()
+
+            # Assumption "/" indicates the ID ... not the best approach, but data does not provide more content
+            ids_ = [(idx, i) for idx, i in enumerate(id_string.split()) if i.startswith("/")]
+            assert(len(ids_) == 1)
+            id_ = ids_[0][1]
+
+            # check if global or system energy
+            # assumption: output identifier uses the wording system
+            #     i.e. system -->  total hourglass energy of system : /10 ( Vehicle_sys )
+
+            data_type = "matsum" if id_string.split()[ids_[0][0]-2] == "system" else "glstat"
+            if id_ not in self._d[data_type]["ids"]:
+                self._d[data_type]["ids"].append(id_)
+
+            if id_string.startswith("total energy"):
+                self._d[data_type]["total_energy"] = None
+
+            if id_string.startswith("total hourglass energy"):
+                self._d[data_type]["hourglass_energy"] = None
+
+            if id_string.startswith("kinetic energy"):
+                self._d[data_type]["kinetic_energy"] = None
+
+            if id_string.startswith("work done by external loading"):
+                self._d[data_type]["external_work"] = None
+
+            if id_string.startswith("work done by contact forces"):
+                self._d[data_type]["sliding_interface_energy"] = None
 
     def _add_ids(self, node, data_type):
         """
@@ -31,10 +107,9 @@ class MadymoData:
         :param data_type:
         :return:
         """
-
         signals = [signal for signal in node.keys() if signal.startswith("SIGNAL")]
         for signal in signals:
-            id_string = ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0])
+            id_string = ''.join([chr(i) for i in list(node[signal].attrs.items())[0][1] if i != 0]).strip()
             id_string = id_string.split(" ")[0]
             assert (id_string not in self._d[data_type]["ids"])
             # if assert: ID is already in id list
@@ -72,7 +147,12 @@ class MadymoData:
         self._d = dict()
 
         with h5py.File(self._madymo_file_path, 'r') as f:
+
+            # 1. extracts available data categories : i.e. glstat, matsum, nodout, elout ... etc
+            #       for each category the sub categories are assigned i.e. glstat --> internal_energy  etc.,
+            #       mapping is done according to the identifiers in the output files i.e.
             f['MODEL_0'].visititems(self._get_available_data_types_dict)
+
             # extend the data dictionary
             dimension = (self._d['nodout']['time'].shape[0], len(self._d['nodout']['ids']))
             data_types_to_be_filled = [i for i in self._d['nodout'].keys() if i != "ids" and i != "time"]
@@ -83,44 +163,69 @@ class MadymoData:
                 if data_type == DataChannelTypesNodout.RX_DISPLACEMENT or \
                         data_type == DataChannelTypesNodout.RY_DISPLACEMENT or \
                         data_type == DataChannelTypesNodout.RZ_DISPLACEMENT:
-                    idx_mady_mo_data = 0 if data_type == DataChannelTypesNodout.RX_DISPLACEMENT else (1 if data_type == DataChannelTypesNodout.RY_DISPLACEMENT else 2)
-                    self._extratct_data(f["MODEL_0/Angular displacements"], data_type, idx_mady_mo_data=idx_mady_mo_data)
+                    idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_DISPLACEMENT else (
+                        1 if data_type == DataChannelTypesNodout.RY_DISPLACEMENT else 2)
+                    self._extratct_data(f["MODEL_0/Angular displacements"], data_type,
+                                        idx_madymo_data=idx_madymo_data)
 
                 elif data_type == DataChannelTypesNodout.RX_VELOCITY or \
                         data_type == DataChannelTypesNodout.RY_VELOCITY or \
                         data_type == DataChannelTypesNodout.RZ_VELOCITY:
-                    idx_mady_mo_data = 0 if data_type == DataChannelTypesNodout.RX_VELOCITY else (1 if data_type == DataChannelTypesNodout.RY_VELOCITY else 2)
-                    self._extratct_data(f["MODEL_0/Angular velocities"], data_type, idx_mady_mo_data=idx_mady_mo_data)
+                    idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_VELOCITY else (
+                        1 if data_type == DataChannelTypesNodout.RY_VELOCITY else 2)
+                    self._extratct_data(f["MODEL_0/Angular velocities"], data_type, idx_madymo_data=idx_madymo_data)
 
                 elif data_type == DataChannelTypesNodout.RX_ACCELERATION or \
                         data_type == DataChannelTypesNodout.RY_ACCELERATION or \
                         data_type == DataChannelTypesNodout.RZ_ACCELERATION:
-                    idx_mady_mo_data = 0 if data_type == DataChannelTypesNodout.RX_ACCELERATION else (1 if data_type == DataChannelTypesNodout.RY_ACCELERATION else 2)
-                    self._extratct_data(f["MODEL_0/Angular accelerations"], data_type, idx_mady_mo_data=idx_mady_mo_data)
+                    idx_madymo_data = 0 if data_type == DataChannelTypesNodout.RX_ACCELERATION else (
+                        1 if data_type == DataChannelTypesNodout.RY_ACCELERATION else 2)
+                    self._extratct_data(f["MODEL_0/Angular accelerations"], data_type,
+                                        idx_madymo_data=idx_madymo_data)
 
                 elif data_type == DataChannelTypesNodout.X_ACCELERATION or \
                         data_type == DataChannelTypesNodout.Y_ACCELERATION or \
                         data_type == DataChannelTypesNodout.Z_ACCELERATION:
-                    idx_mady_mo_data = 1 if data_type == DataChannelTypesNodout.X_ACCELERATION else (2 if data_type == DataChannelTypesNodout.Y_ACCELERATION else 3)
-                    self._extratct_data(f["MODEL_0/Linear accelerations"], data_type,idx_mady_mo_data=idx_mady_mo_data)
+                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_ACCELERATION else (
+                        2 if data_type == DataChannelTypesNodout.Y_ACCELERATION else 3)
+                    self._extratct_data(f["MODEL_0/Linear accelerations"], data_type, idx_madymo_data=idx_madymo_data)
 
                 elif data_type == DataChannelTypesNodout.X_VELOCITY or \
                         data_type == DataChannelTypesNodout.Y_VELOCITY or \
                         data_type == DataChannelTypesNodout.Z_VELOCITY:
-                    idx_mady_mo_data = 1 if data_type == DataChannelTypesNodout.X_VELOCITY else (2 if data_type == DataChannelTypesNodout.Y_VELOCITY else 3)
-                    self._extratct_data(f["MODEL_0/Linear velocities"], data_type, idx_mady_mo_data=idx_mady_mo_data)
+                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_VELOCITY else (
+                        2 if data_type == DataChannelTypesNodout.Y_VELOCITY else 3)
+                    self._extratct_data(f["MODEL_0/Linear velocities"], data_type, idx_madymo_data=idx_madymo_data)
 
                 elif data_type == DataChannelTypesNodout.X_COORDINATE or \
                         data_type == DataChannelTypesNodout.Y_COORDINATE or \
                         data_type == DataChannelTypesNodout.Z_COORDINATE:
-                    idx_mady_mo_data = 1 if data_type == DataChannelTypesNodout.X_COORDINATE else (2 if data_type == DataChannelTypesNodout.Y_COORDINATE else 3)
-                    self._extratct_data(f["MODEL_0/Linear positions"], data_type, idx_mady_mo_data=idx_mady_mo_data)
+                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_COORDINATE else \
+                        (2 if data_type == DataChannelTypesNodout.Y_COORDINATE else 3)
+                    self._extratct_data(f["MODEL_0/Linear positions"], data_type, idx_madymo_data=idx_madymo_data)
 
                 elif data_type == DataChannelTypesNodout.X_DISPLACEMENT or \
                         data_type == DataChannelTypesNodout.Y_DISPLACEMENT or \
                         data_type == DataChannelTypesNodout.Z_DISPLACEMENT:
-                    idx_mady_mo_data = 1 if data_type == DataChannelTypesNodout.X_DISPLACEMENT else (2 if data_type == DataChannelTypesNodout.Y_DISPLACEMENT else 3)
-                    self._extratct_data(f["MODEL_0/Linear displacements"], data_type, idx_mady_mo_data=idx_mady_mo_data)
+                    idx_madymo_data = 1 if data_type == DataChannelTypesNodout.X_DISPLACEMENT else (
+                        2 if data_type == DataChannelTypesNodout.Y_DISPLACEMENT else 3)
+                    self._extratct_data(f["MODEL_0/Linear displacements"], data_type, idx_madymo_data=idx_madymo_data)
+
+            dimension = (self._d['matsum']['time'].shape[0], len(self._d['matsum']['ids']))
+            energy_to_be_filled = [i for i in self._d['matsum'].keys() if i != "ids" and i != "time"]
+            for energy_type in energy_to_be_filled:
+                self._d['matsum'][energy_type] = np.empty(dimension)
+                self._d['matsum'][energy_type][:] = np.nan
+                self._extract_data_energy(f["MODEL_0/Energy output"], 'matsum', self._d["matsum"]["ids"], energy_type)
+
+            dimension = (self._d['glstat']['time'].shape[0],len(self._d['glstat']['ids']))
+            energy_to_be_filled = [i for i in self._d['glstat'].keys() if i != "ids" and i != "time"]
+            for energy_type in energy_to_be_filled:
+                self._d['glstat'][energy_type] = np.empty(dimension)
+                self._d['glstat'][energy_type][:] = np.nan
+                self._extract_data_energy(f["MODEL_0/Energy output"], 'glstat', self._d["glstat"]["ids"], energy_type)
+                self._d["glstat"][energy_type] = self._d["glstat"][energy_type].flatten()
+                a = 0
 
         logger = ConsoleLogger()
         self.dynasaur_definitions = DynasaurDefinitions(logger)
@@ -183,15 +288,21 @@ class MadymoData:
 
                 if 'glstat' not in self._d.keys():
                     if node.parent.name.split("/")[-1].startswith("Energy output"):
-                        self._d['glstat'] = {"time": None}
+                        self._d['glstat'] = {"ids": [], "time": None}
+
+                if 'matsum' not in self._d.keys():
+                    if node.parent.name.split("/")[-1].startswith("Energy output"):
+                        self._d['matsum'] = {"ids": [], "time": None}
 
                 if node.parent.name.split("/")[-1].startswith("Energy output"):
                     # TODO
                     # self._d['glstat'][DataChannelTypesNodout.RX_ACCELERATION] = None
                     # self._d['glstat'][DataChannelTypesNodout.RY_ACCELERATION] = None
                     # self._d['glstat'][DataChannelTypesNodout.RZ_ACCELERATION] = None
-                    # self._add_ids(node.parent, data_type="glstat")
+
+                    self._add_energy_ids(node.parent, data_type="glstat")
                     self._add_time(node.parent, data_type="glstat")
+                    self._add_time(node.parent, data_type="matsum")
 
                 if node.parent.name.split("/")[-1].startswith("Angular accelerations"):
                     self._d['nodout'][DataChannelTypesNodout.RX_ACCELERATION] = None
@@ -273,4 +384,3 @@ class MadymoData:
                     return []
             else:
                 return []
-
