@@ -118,19 +118,26 @@ class DataVisualizationController(PluginInterface, Plugin):
         rows = []
         values = []
         d = self._get_padded_data_dict()
+
+        # header information
         for part_of in d.keys():
             for diagram_name in d[part_of].keys():
                 rows.append(part_of + ":" + diagram_name + ":" + d[part_of][diagram_name]["x_name"])
                 rows.append(part_of + ":" + diagram_name + ":" + d[part_of][diagram_name]["y_name"])
 
+        # actual data
         for part_of in d.keys():
             for diagram_name in d[part_of].keys():
                 values.append(d[part_of][diagram_name]["X"])
                 values.append(d[part_of][diagram_name]["Y"])
 
+        list_lengths = [len(i) for i in values]
+        assert(all([a == list_lengths[0] for a in list_lengths]))
+
         with open(path, 'w') as csvfile:
             writer = csv.writer(csvfile, delimiter=';', lineterminator='\n')
             writer.writerow(rows)
+
             t_m = list(zip(*values))
             for key in t_m:
                 writer.writerow(key)
@@ -195,12 +202,14 @@ class DataVisualizationController(PluginInterface, Plugin):
         length = DataVisualizationController._get_maximum_length(d)
         for part_of in d.keys():
             for diagram_name in d[part_of].keys():
-                if len(d[part_of][diagram_name]["X"]) < length:
-                    index = len(d[part_of][diagram_name]["X"])
+                if len(d[part_of][diagram_name]["X"]) < length or len(d[part_of][diagram_name]["Y"]) < length:
+                    index_x = len(d[part_of][diagram_name]["X"])
                     d[part_of][diagram_name]["X"] = np.concatenate(
-                        (d[part_of][diagram_name]["X"], ['-'] * (length - index)))
+                        (d[part_of][diagram_name]["X"], ['-'] * (length - index_x)))
+
+                    index_y = len(d[part_of][diagram_name]["Y"])
                     d[part_of][diagram_name]["Y"] = np.concatenate(
-                        (d[part_of][diagram_name]["Y"], ['-'] * (length - index)))
+                        (d[part_of][diagram_name]["Y"], ['-'] * (length - index_y)))
         return d
 
     @staticmethod
