@@ -137,8 +137,7 @@ class Plugin(object):
             if not procesed_data is None:
                 return procesed_data
             else:
-                self._logger.emit(LOGConstants.ERROR[0],
-                                  function_name + StandardFunctionsDefinition.ERROR_NOT_STANDARD_FUNCTION)
+                self._logger.emit(LOGConstants.ERROR[0], "Calculation of " + function_name + " aborted!")
 
         elif JsonConstants.VALUE in json_object.keys():
             return np.array(json_object[JsonConstants.VALUE])
@@ -205,6 +204,9 @@ class Plugin(object):
             if key == "VOLUME":
                 continue
 
+            if self._data[key].get_interpolated_time() is None:
+                return
+
             if start_time is not None and end_time is not None:
                 indices = np.argwhere(
                     (start_time * self._units.second() <= self._data[key].get_interpolated_time()) &
