@@ -290,6 +290,13 @@ class VPSDataConstant:
     NODE = "NODE"
     SECFORC = "secforc"
     SECTION = "SECTION"
+    RCFORC = "rcforc"
+    CONTACT = "CONTACT"
+    GLSTAT = "glstat"
+    ENERGY_GLOBAL = "MODEL"
+    MATSUM = "matsum"
+    ENERGY_PART = "PART"
+
 
     #nodout
     COORDINATE = "COORDINATE"
@@ -305,6 +312,13 @@ class VPSDataConstant:
     SECTION_FORCE = "Section_Force"
     SECTION_MOMENT = "Section_Moment"
 
+    #rcforc
+    CONTACT_FORCE = "Contact_Force"
+
+    #glstat
+    ENERGY_GLOBAL_EXTERNAL = "TEXT"
+    ENERGY_GLOBAL_ENKIT = "ENKIT"
+
 class DataChannelTypesNodout:
     X_COORDINATE = "x_coordinate"
     Y_COORDINATE = "y_coordinate"
@@ -335,6 +349,18 @@ class DataChannelTypesNodout:
     RZ_ACCELERATION = "rz_acceleration"
 
 
+class DataChannelTypesContact:
+    X_FORCE = "x_force"
+    Y_FORCE = "y_force"
+    Z_FORCE = "z_force"
+
+class DataChannelTypesGlobalEnergy:
+    EXTERNAL_WORK = "external_work"
+    INTERNAL_ENERGY = "internal_energy"
+    KINETIC_ENERGY = "kinetic_energy"
+    TOTAL_ENERGY = "total_energy"
+
+
 class DataChannelTypesSecforc:
     X_CENTROID = "x_centroid"
     Y_CENTROID = "y_centroid"
@@ -343,7 +369,9 @@ class DataChannelTypesSecforc:
     X_FORCE = "x_force"
     Y_FORCE = "y_force"
     Z_FORCE = "z_force"
+    TOTAL_FORCE = "total_force"
 
     X_MOMENT = "x_moment"
     Y_MOMENT = "y_moment"
     Z_MOMENT = "z_moment"
+    TOTAL_MOMENT = "total_moment"
